<?php

namespace Litecms\Bookings\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Bookings\Interfaces\BookingRepositoryInterface;

class BookingPublicController extends BaseController
{
    // use BookingWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Booking\Interfaces\BookingRepositoryInterface $booking
     *
     * @return type
     */
    public function __construct(BookingRepositoryInterface $booking)
    {
        $this->repository = $booking;
        parent::__construct();
    }

    /**
     * Show booking's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $bookings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$bookings::booking.names'))
            ->view('bookings::booking.index')
            ->data(compact('bookings'))
            ->output();
    }


    /**
     * Show booking.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $booking = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$booking->name . trans('bookings::booking.name'))
            ->view('bookings::booking.show')
            ->data(compact('booking'))
            ->output();
    }

}
