<?php

namespace Litecms\Bookings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Bookings\Models\Booking;

class BookingPolicy
{

    /**
     * Determine if the given user can view the booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function view(UserPolicy $user, Booking $booking)
    {
        if ($user->canDo('bookings.booking.view') && $user->isAdmin()) {
            return true;
        }

        return $booking->user_id == user_id() && $booking->user_type == user_type();
    }

    /**
     * Determine if the given user can create a booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bookings.booking.create');
    }

    /**
     * Determine if the given user can update the given booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function update(UserPolicy $user, Booking $booking)
    {
        if ($user->canDo('bookings.booking.edit') && $user->isAdmin()) {
            return true;
        }

        return $booking->user_id == user_id() && $booking->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Booking $booking)
    {
        return $booking->user_id == user_id() && $booking->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Booking $booking)
    {
        if ($user->canDo('bookings.booking.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given booking.
     *
     * @param UserPolicy $user
     * @param Booking $booking
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Booking $booking)
    {
        if ($user->canDo('bookings.booking.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
